@@ -3,12 +3,9 @@ from django import template
 from carton.cart import Cart
 from carton.settings import CART_TEMPLATE_TAG_NAME
 
-
 register = template.Library()
 
-
-@register.assignment_tag(takes_context=True, name=CART_TEMPLATE_TAG_NAME)
-def get_cart(context, session_key=None):
+def get_cart(context, session_key=None, model=None, cart_class=Cart):
     """
     Make the cart object available in template.
 
@@ -21,4 +18,6 @@ def get_cart(context, session_key=None):
         {% endfor %}
     """
     request = context['request']
-    return Cart(request.session, session_key)
+    return cart_class(request.session, session_key=session_key, model=model)
+
+register.assignment_tag(takes_context=True, name=CART_TEMPLATE_TAG_NAME)(get_cart)
